# coding: utf-8

"""
    Tator REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.6.5
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class AuxiliaryFileDefinition(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host': 'str',
        'http_auth': 'str',
        'mime': 'str',
        'name': 'str',
        'path': 'str',
        'size': 'int'
    }

    attribute_map = {
        'host': 'host',
        'http_auth': 'http_auth',
        'mime': 'mime',
        'name': 'name',
        'path': 'path',
        'size': 'size'
    }

    def __init__(self, host=None, http_auth=None, mime=None, name=None, path=None, size=None, local_vars_configuration=None):  # noqa: E501
        """AuxiliaryFileDefinition - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._host = None
        self._http_auth = None
        self._mime = None
        self._name = None
        self._path = None
        self._size = None
        self.discriminator = None

        if host is not None:
            self.host = host
        if http_auth is not None:
            self.http_auth = http_auth
        if mime is not None:
            self.mime = mime
        if name is not None:
            self.name = name
        self.path = path
        if size is not None:
            self.size = size

    @property
    def host(self):
        """
        If supplied will use this instead of currently connected host, e.g. https://example.com

        :return: The host of this AuxiliaryFileDefinition. 
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        If supplied will use this instead of currently connected host, e.g. https://example.com

        :param host: The host of this AuxiliaryFileDefinition.
        :type: str
        """

        self._host = host

    @property
    def http_auth(self):
        """
        If specified will be used for HTTP authorization in request for media, i.e. \"bearer TOKEN\".

        :return: The http_auth of this AuxiliaryFileDefinition. 
        :rtype: str
        """
        return self._http_auth

    @http_auth.setter
    def http_auth(self, http_auth):
        """
        If specified will be used for HTTP authorization in request for media, i.e. \"bearer TOKEN\".

        :param http_auth: The http_auth of this AuxiliaryFileDefinition.
        :type: str
        """

        self._http_auth = http_auth

    @property
    def mime(self):
        """
        Example mime: \"text/csv\".

        :return: The mime of this AuxiliaryFileDefinition. 
        :rtype: str
        """
        return self._mime

    @mime.setter
    def mime(self, mime):
        """
        Example mime: \"text/csv\".

        :param mime: The mime of this AuxiliaryFileDefinition.
        :type: str
        """

        self._mime = mime

    @property
    def name(self):
        """
        Name of the file.

        :return: The name of this AuxiliaryFileDefinition. 
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Name of the file.

        :param name: The name of this AuxiliaryFileDefinition.
        :type: str
        """

        self._name = name

    @property
    def path(self):
        """
        Relative URL to the file.

        :return: The path of this AuxiliaryFileDefinition. 
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Relative URL to the file.

        :param path: The path of this AuxiliaryFileDefinition.
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def size(self):
        """
        File size in bytes.

        :return: The size of this AuxiliaryFileDefinition. 
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        File size in bytes.

        :param size: The size of this AuxiliaryFileDefinition.
        :type: int
        """

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuxiliaryFileDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuxiliaryFileDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.6.5
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ..configuration import Configuration


class UserUpdate(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'clear_avatar': 'int',
        'clear_profile_keys': 'list[str]',
        'elemental_id': 'str',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'new_avatar': 'str',
        'password': 'str',
        'reset_token': 'str',
        'set_profile_keys': 'object'
    }

    attribute_map = {
        'clear_avatar': 'clear_avatar',
        'clear_profile_keys': 'clear_profile_keys',
        'elemental_id': 'elemental_id',
        'email': 'email',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'new_avatar': 'new_avatar',
        'password': 'password',
        'reset_token': 'reset_token',
        'set_profile_keys': 'set_profile_keys'
    }

    def __init__(self, clear_avatar=0, clear_profile_keys=None, elemental_id=None, email=None, first_name=None, last_name=None, new_avatar=None, password=None, reset_token=None, set_profile_keys=None, local_vars_configuration=None):  # noqa: E501
        """UserUpdate - a model defined in OpenAPI"""
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._clear_avatar = None
        self._clear_profile_keys = None
        self._elemental_id = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._new_avatar = None
        self._password = None
        self._reset_token = None
        self._set_profile_keys = None
        self.discriminator = None

        if clear_avatar is not None:
            self.clear_avatar = clear_avatar
        if clear_profile_keys is not None:
            self.clear_profile_keys = clear_profile_keys
        if elemental_id is not None:
            self.elemental_id = elemental_id
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if new_avatar is not None:
            self.new_avatar = new_avatar
        if password is not None:
            self.password = password
        if reset_token is not None:
            self.reset_token = reset_token
        if set_profile_keys is not None:
            self.set_profile_keys = set_profile_keys

    @property
    def clear_avatar(self):
        """
        Set to >0 to clear the current avatar of the user

        :return: The clear_avatar of this UserUpdate. 
        :rtype: int
        """
        return self._clear_avatar

    @clear_avatar.setter
    def clear_avatar(self, clear_avatar):
        """
        Set to >0 to clear the current avatar of the user

        :param clear_avatar: The clear_avatar of this UserUpdate.
        :type: int
        """

        self._clear_avatar = clear_avatar

    @property
    def clear_profile_keys(self):
        """
        Clear the given keys from the profile dictionary

        :return: The clear_profile_keys of this UserUpdate. 
        :rtype: list[str]
        """
        return self._clear_profile_keys

    @clear_profile_keys.setter
    def clear_profile_keys(self, clear_profile_keys):
        """
        Clear the given keys from the profile dictionary

        :param clear_profile_keys: The clear_profile_keys of this UserUpdate.
        :type: list[str]
        """

        self._clear_profile_keys = clear_profile_keys

    @property
    def elemental_id(self):
        """
        Unique ID for a user across clusters/deployments

        :return: The elemental_id of this UserUpdate. 
        :rtype: str
        """
        return self._elemental_id

    @elemental_id.setter
    def elemental_id(self, elemental_id):
        """
        Unique ID for a user across clusters/deployments

        :param elemental_id: The elemental_id of this UserUpdate.
        :type: str
        """

        self._elemental_id = elemental_id

    @property
    def email(self):
        """
        Email address of user.

        :return: The email of this UserUpdate. 
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Email address of user.

        :param email: The email of this UserUpdate.
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """
        First name of user.

        :return: The first_name of this UserUpdate. 
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        First name of user.

        :param first_name: The first_name of this UserUpdate.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Last name of user.

        :return: The last_name of this UserUpdate. 
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Last name of user.

        :param last_name: The last_name of this UserUpdate.
        :type: str
        """

        self._last_name = last_name

    @property
    def new_avatar(self):
        """
        b64 encoded image to use for the avatar of the user.This file is verified to meet system constraints:    - Less than 1Mb     - a mimetype of image/png or image/jpg

        :return: The new_avatar of this UserUpdate. 
        :rtype: str
        """
        return self._new_avatar

    @new_avatar.setter
    def new_avatar(self, new_avatar):
        """
        b64 encoded image to use for the avatar of the user.This file is verified to meet system constraints:    - Less than 1Mb     - a mimetype of image/png or image/jpg

        :param new_avatar: The new_avatar of this UserUpdate.
        :type: str
        """

        self._new_avatar = new_avatar

    @property
    def password(self):
        """
        Account password.

        :return: The password of this UserUpdate. 
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Account password.

        :param password: The password of this UserUpdate.
        :type: str
        """

        self._password = password

    @property
    def reset_token(self):
        """
        Password reset token generated by PasswordReset object.

        :return: The reset_token of this UserUpdate. 
        :rtype: str
        """
        return self._reset_token

    @reset_token.setter
    def reset_token(self, reset_token):
        """
        Password reset token generated by PasswordReset object.

        :param reset_token: The reset_token of this UserUpdate.
        :type: str
        """

        self._reset_token = reset_token

    @property
    def set_profile_keys(self):
        """
        Key/Value Pairs to set atomically

        :return: The set_profile_keys of this UserUpdate. 
        :rtype: object
        """
        return self._set_profile_keys

    @set_profile_keys.setter
    def set_profile_keys(self, set_profile_keys):
        """
        Key/Value Pairs to set atomically

        :param set_profile_keys: The set_profile_keys of this UserUpdate.
        :type: object
        """

        self._set_profile_keys = set_profile_keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserUpdate):
            return True

        return self.to_dict() != other.to_dict()



import os

from ._upload_file import _upload_file


def upload_generic_file(
    api, file_type, path, description, name=None, attributes=None, timeout=None
):
    """Upload a file to the File storage location.

    Example:

    .. code-block:: python

        api = tator.get_api(host, token)
        for progress, response in tator.util.upload_generic_file(api, project_id, path):
            print(f"Upload progress: {progress}%")
        print(response)

    :param api: :class:`tator.TatorApi` object.
    :param file_type: Unique integer identifying a `FileType`.
    :param path: Path to the file.
    :param description: Description of the file to be uploaded.
    :param name: [Optional] Name of temporary file in database. Defaults to basename of path.
    :param attributes: [Optional] Attributes to set on the uploaded file.
    :param timeout: [Optional] Timeout for the :meth:`tator.util._upload_file._upload_file`
                    operation.
    :returns: Generator that yields tuple containing progress (0-100) and a response. The response
              is `None` until the last yield, when the response is the updated response object from
              :meth:`tator.util.TatorApi.get_file`.
    """
    project = api.get_file_type(file_type).project
    if name is None:
        name = os.path.basename(path)
    file_spec = {"name": name, "type": file_type, "description": description}
    if attributes is not None:
        file_spec["attributes"] = attributes

    response = api.create_file(project=project, file_spec=file_spec)
    file_id = response.id
    upload_kwargs = {
        "api": api,
        "project": project,
        "path": path,
        "file_id": file_id,
    }
    if timeout is not None:
        upload_kwargs["timeout"] = timeout

    for progress, upload_info in _upload_file(**upload_kwargs):
        yield (progress, None)

    api.update_file(id=file_id, file_update={"path": upload_info.key})
    response = api.get_file(file_id)
    yield (100, response)
